# Introducción

![[portada.png]]

El presente documento es una guía para la redacción de protocolos de investigación para el TecNM. Los sitios principales que requieren así como documentos del curso los puedes encontrar en el presente repositorio -**protocolos-tecnm**- .

Sitios de interés:
- Página para llenar CVU en el TecNM: https://cvu.dpii.tecnm.mx
- Página para ingresar proyectos: https://proyectos.dpii.tecnm.mx
- Repositorios del curso: https://gitea.itmorelia.com
- [Archivo muestra realizado en el curso](https://gitea.itmorelia.com/protocolos-tecnm-workshop/protocolo-example)
- [Vídeo de instalación de Obsidian](https://youtu.be/VnUIpMJSoME)
- [Notas colaborativas](https://pad.riseup.net/p/protocolos-tecnm)

Entonces, se recomienda al participante verificar que está activo y/o tiene cuenta en la página del CVU del TecNM, en caso de no tener cuenta, debe de crear una con los datos de su plaza. En caso de ser profesor por honorarios, podrá registrarse pero solo podrá participar como colaborador de hasta dos proyectos. 

# Pantalla principal

Una vez registrado con el CVU y permitiendo el acceso a datos y notificaciones entre aplicaciones del TecNM, es posible ingresar al menú de las convocatorias para registrar un nuevo proyecto; esto solo es posible durante periodos hábiles. Toda la información debe ser ingresada al sistema a través de la [página de los proyectos.](https://proyectos.dpii.tecnm.mx/)

![captura de pantalla de las convocatorias](convocatorias.jpg)

Cuando se inicia el registro del proyecto se solicitará[^1]:
- Título
- Objetivos general
- Objetivos específicos
- Modalidad
- **LGAC** | Deben estar registradas ante el TecNM

[^1]: Una vez registrado el proyecto únicamente se pueden cambiar los objetivos, modalidad y LGAC.
## Título del proyecto

El título del proyecto será el primer contacto con los revisores. Por lo tanto se sugiere que este punto sea cubierto con mucho cuidado y después de un rato de revisión. Evitar usar títulos como:

> **Diseño y construcción de un sistema de adquisición de datos para el monitoreo de variables climatológicas.**
> **Desarrollo de un sistema de un rectificador trifásico para el control de un horno al vacío.**

Se sugiere que el título de proyecto trate de responder las siguientes preguntas:
- ¿Qué voy a hacer?
- ¿Cómo lo voy a hacer?
- ¿Para qué lo voy a hacer?

Considerando los títulos de ejemplo anteriores y usando como base las preguntas a responder se sugieren usar los siguientes estilos de títulos:
> **Análisis de variables climatológicas mediante un sistema de adquisición de datos basado en IoT para estudios de erosión en tierras de cultivo.**
> **Determinación de los parámetros de operación más relevantes en un horno de vacío por medio de un rectificador trifásico en el desarrollo de aleaciones de acero automotriz.**


*En las siguientes secciones se describirán en detalle los tres rubros principales de la `Información Básica del Proyecto (IBP)`.*

# Información básica del proyecto

La pantalla principal del registro del proyecto consta de tres grandes secciones requeridas para el envío de la propuesta de proyecto al TecNM y la mayoría de otras plataformas. Las secciones tienen como finalidad definir el alcance del proyecto, sus participantes y productos esperados, así como también visualizar una posible planificación de actividades y ejecución del recurso. Estas secciones son:
- Protocolo de investigación y desarrollo académico
- Planeación del proyecto
- Documentación y seguimiento

![[informacion.jpg]]

⚠️ **Desde este punto, recomiendo el uso de alguna herramienta de texto para crear la plantilla permita trabajar fuera de línea en el llenado de los campos requeridos** ⚠️
# Protocolo de investigación y desarrollo académico
## Protocolo
 
 El documento del protocolo del proyecto tiene como intención identificar los puntos clave del trabajo, tanto para el revisor como para el autor, a través de la exposición de la problemática a resolver y el expertise de los participantes. Para la postulación del documento se requiere el llenado de los siguientes campos/rubros:
 - Resumen
 - Introducción
 - Antecedentes
 - Objetivo general
 - Objetivos específicos
 - Marco teórico
 - Impacto o beneficio
 - Metodología
 - Vinculación
 - Referencias
 - Lugares donde se va a desarrollar el proyecto
 - Infraestructura


![[protocolo-partes.jpg]]


## Resumen
El resumen es el **primer contacto de nuestro proyecto de investigación con los revisores**, éste debe de ser contundente --impacto, problemática, enfoque, alcance, resultados esperados--.  Procura que sea *una descripción concisa del problema, objetivos, metodología, y resultados esperados.*

**Mi sugerencia es dejar este punto hasta el final, ya que la definición del proyecto tomará forma conforme se estructure y formule el protocolo. **

No obstante, hay quienes desarrollan un primer borrador con ideas generales para tener una idea del contenido y enfoque del proyecto.

## Introducción 

Se sugiere que la introducción contenga el planteamiento general del problema. Explicar el contexto actual del tópico, por qué es importante abordarlo y qué impacto tendría resolverlo.

Se sugiere intentar contestar las siguientes preguntas:
- ¿Cuál es el problema que quiero resolver?
- ¿Por qué es importante el problema que quiero resolver?
- ¿Cómo voy a resolver el problema propuesto?
- ¿Existen casos parecidos del problema que quiero resolver?

Como guía en la redacción de esta sección, primero se muestra el ejemplo de una introducción que toca los puntos que se esperan abordar en la sección, después se define una plantilla general que nos puede guiar a lograr el mismo resultado u orientarnos en la redacción de la introducción.

### Ejemplo

> [!EXAMPLE] Ejemplo de introducción
> **Título:** Diseño de mezclas poliméricas flexibles a partir de acido polilactido y elastómeros para aplicaciones industriales
> 
> En los últimos años, el acido polilactido (PLA) ha captado una atención creciente en el ámbito científico e industrial debido a su carácter biodegradable, el cual representa una alternativa ambientalmente amigable frente a los plásticos convencionales derivados del petróleo [1]. Esta característica, junto con sus propiedades físico-químicas, ha permitido su posicionamiento como un material con importantes beneficios económicos, particularmente en aplicaciones sostenibles [2]. La PLA es un polímero que se obtiene a partir de recursos renovables, como el maíz, mediante el proceso de polimerización del monómero lactido [3]. Este biopolímero ha demostrado un alto potencial de aplicación en diversas áreas, destacando su uso en el sector biomédico [4], por ejemplo, en la fabricación de dispositivos médicos, estructuras temporales y materiales para liberación controlada de fármacos. Asimismo, ha sido objeto de estudio en el desarrollo de materiales estructurales dentro del campo de la ingeniería [5,6].
> 
> Sin embargo, a pesar de estas ventajas, uno de los principales desafíos que limita su implementación a escala industrial es su baja resistencia al impacto. Se ha observado que la PLA, en su forma pura, tiende a ser quebradiza y frágil, lo cual compromete su desempeño en aplicaciones que requieren cierto grado de ductilidad y tenacidad [7,8]. En consecuencia, se  exploran métodos que mejoren su comportamiento mecánico sin comprometer su biodegradabilidad ni su origen renovable [9].
> 
> Una estrategia ampliamente investigada para mejorar las propiedades mecánicas de los polímeros como la PLA consiste en la incorporación de partículas de caucho, lo cual permite aumentar la capacidad de absorción de energía bajo carga y reducir la fragilidad del material [10]. Existen numerosos estudios que documentan la modificación de la PLA mediante el uso de distintas formulaciones de caucho, lo que ha llevado al desarrollo de compuestos con mejor resistencia al impacto. Por ejemplo, Penney y colaboradores demostraron que es posible obtener mezclas de PLA con caucho mediante técnicas de mezclado físico [11], mientras que investigaciones más recientes, como las de Hillier, han evidenciado mejoras sustanciales en la resistencia y tenacidad de estos nuevos materiales [12].
> 
> **A pesar de estos avances, se ha prestado poca atención a la elección del tipo de caucho más adecuado para lograr una compatibilidad óptima con la matriz de PLA. Aunque se ha documentado el efecto positivo del caucho sobre las propiedades mecánicas del sistema [13], son escasos los estudios que se enfocan en establecer criterios claros para seleccionar el componente elastomérico más apropiado según la aplicación final o el proceso de fabricación.**
> 
> En este contexto, **la presente propuesta de investigación tiene como objetivo establecer un conjunto de criterios para la selección racional de un componente elastomérico que permita mejorar la flexibilidad y resistencia al impacto de la polilactida**. Con base en dichos criterios, se plantea la síntesis experimental y la caracterización de mezclas poliméricas utilizando PLA como matriz principal y un caucho hidrocarbonado, específicamente poliisopreno (PI), como agente modificador.
> 
> Se espera que la combinación de estas dos rutas de polimerización, estructural y mecánicamente distintas, dé lugar a un nuevo tipo de copolímero o mezcla polimérica con morfología más homogénea y propiedades mejoradas. Particularmente, se investigará cómo la inclusión del PI influye en la distribución de fases, la flexibilidad y la respuesta mecánica del material resultante.
> 
> Este estudio tiene el potencial de contribuir al desarrollo de biopolímeros más competitivos, ampliando el espectro de aplicaciones de la PLA en sectores como el automotriz, biomédico y del envasado, donde se requieren materiales sostenibles con mejor desempeño mecánico.


### Guía para escribir la introducción


> [!TIP] **Establecer la importancia del campo de estudio**
> En este primer bloque, debes:
> - Resaltar **por qué el tema general de investigación es relevante** (ambiental, económico, científico, social, etc.).
> - **Proporcionar información de fondo** (datos, hechos, avances recientes, tendencias) preferentemente sustentada por literatura científica actual.
> - Aclarar **los términos clave** del título o del planteamiento, especialmente si son técnicos o especializados.
> - Delimitar **el área específica del problema** que se abordará y el enfoque actual en la investigación sobre ese tema.
>
>📌 _Ejemplo:_“El acido polilactido (PLA) ha ganado relevancia en el desarrollo de materiales biodegradables debido a su origen renovable y su potencial aplicación en sectores como el biomédico y el de envases sostenibles…”

  

> [!TIP] Describir la investigación previa y sus contribuciones
> 
>   
> 
> Aquí debes:
> 
> - Exponer brevemente **qué investigaciones anteriores se han hecho** sobre el tema o sobre temas similares.
>     
> - Señalar los **avances más importantes** o descubrimientos relevantes.
>     
> - Mencionar **quiénes han contribuido al área** y cómo.
>   
> 📌 _Ejemplo:_ “Diversos autores han explorado la modificación de PLA mediante la incorporación de elastómeros, con resultados positivos en la mejora de su resistencia al impacto…”


> [!TIP] Identificar el vacío en la investigación y formular el problema
> Esta parte es clave para justificar tu trabajo:
> - Señala **qué aspectos aún no han sido abordados completamente** en los estudios previos preliminares.
> - Especifica **el vacío** que tu investigación busca llenar.
> - Formula de forma clara **el problema específico** que abordarás.
>  
>📌 _Ejemplo:_ “A pesar de los avances, aún no se cuenta con criterios sistemáticos para seleccionar el tipo de caucho más adecuado para mezclas con PLA, ni se ha evaluado suficientemente el efecto del poliisopreno en su desempeño mecánico…”
> 

  

> [!TIP] Presentar la propuesta de investigación
>
> Para cerrar la introducción:
> - Plantea **la hipótesis o predicción general** que guiará el estudio.
> - Describe brevemente **qué hará tu investigación** y cómo contribuirá al conocimiento del área.    
> 
> 📌 _Ejemplo:_ “La presente investigación propone establecer criterios para la selección de un caucho hidrocarbonado compatible con PLA y evaluar, mediante caracterización experimental, su efecto en la flexibilidad de las mezclas obtenidas.”

Si sigues esta estructura, tu introducción cumplirá con los requisitos de claridad, coherencia lógica y justificación científica, elementos fundamentales para un protocolo sólido y convincente.


## Antecedentes

Los **antecedentes** profundizan en lo que **otros autores han investigado previamente** sobre el mismo tema o temas relacionados. Su objetivo es **mostrar el estado del arte** y justificar que **existe un vacío en el conocimiento** que tu investigación pretende abordar.

**📌 Contenido típico de los antecedentes:**
- Revisión de estudios previos relevantes.
- Métodos, enfoques o soluciones que otros han aplicado.
- Resultados clave obtenidos por otros investigadores.
- **Limitaciones o lagunas** en esos estudios.
- Fundamentación teórica y técnica del problema.



> [!EXAMPLE] Antecedentes en proyecto: monitoreo de la degradación de forma indirecta mediante espectroscopía de impedancia electroquímica (EIS).
> 
> La producción de hidrógeno por electrólisis del agua es una tecnología clave en el desarrollo de sistemas energéticos sostenibles. Entre las diversas configuraciones, los electrolizadores de agua alcalina se han consolidado como una alternativa confiable y de bajo costo frente a tecnologías más recientes como los electrolizadores de membrana de intercambio protónico (PEM) o de óxido sólido (SOEC) [1,2,3,4]. No obstante, estos sistemas enfrentan desafíos operativos significativos que limitan su eficiencia y durabilidad a largo plazo [2,5,6,7].
>
> Como se indicó previamente, uno de los principales problemas operativos identificados es la **degradación progresiva de los electrodos**, especialmente del ánodo. Durante el proceso de electrólisis, la formación constante de burbujas de gas, particularmente de oxígeno en el ánodo, genera fenómenos de oxidación acelerada que inducen la formación de capas de óxido sobre la superficie del electrodo. Esta oxidación reduce su conductividad eléctrica y disminuye su eficiencia electroquímica. Asimismo, factores como el sobrecalentamiento del electrolito y la disociación de sus componentes contribuyen al deterioro del sistema, generando condiciones inestables que afectan la pureza y la tasa de producción del hidrógeno [@ref7, @ref38].
> 
> En respuesta a estos problemas, diversos estudios han intentado **minimizar el desgaste de los electrodos** mediante enfoques como:
> 
> - La aplicación de **recubrimientos protectores** (como óxidos metálicos estables o materiales cerámicos) para reducir el contacto directo con el electrolito agresivo[10, 12, 14].
> - La modificación de la **composición del electrolito** mediante aditivos que estabilicen el pH y reduzcan la corrosión [15,16,17].
> - La optimización de **condiciones de operación** como temperatura, corriente y tiempo de uso para evitar fenómenos de sobrecarga térmica o electroquímica.
>   
> Si bien estas estrategias han mostrado mejoras parciales, su efectividad a largo plazo depende en gran medida del **monitoreo constante del estado del sistema**, lo que ha llevado a la búsqueda de métodos indirectos para evaluar el deterioro interno sin necesidad de interrumpir la operación.
> 
> Una técnica ampliamente utilizada para este fin es la **Espectroscopía de Impedancia Electroquímica (EIS)**, la cual permite caracterizar la respuesta eléctrica del sistema a través de la medición de parámetros como la resistencia de transferencia de carga, la resistencia óhmica y la capacitancia de doble capa. Estos parámetros pueden correlacionarse con procesos de degradación interna, permitiendo inferir el estado de los electrodos sin intervención física directa [@ref3; @ref31; @ref35]. Por ejemplo, Zhou et al. (2018) aplicaron EIS en condiciones de operación cíclica para identificar la pérdida gradual de área activa en ánodos de níquel recubiertos [@ref36]. De forma similar, Al-Mamun et al. (2021) mostraron que un aumento progresivo en la resistencia de carga puede ser un buen predictor del nivel de pasivación superficial en electrodos alcalinos [@ref34].
> 
> No obstante, **la mayoría de estos estudios han sido realizados en condiciones controladas y no durante la operación real del electrolizador**, lo que limita su aplicabilidad como herramienta de monitoreo continuo. Además, **la integración de la EIS con estrategias de modelado paramétrico o sistemas de observabilidad dinámica** ha sido poco explorada, a pesar de su potencial para implementar sistemas de diagnóstico inteligente.
> 
> Recientemente, algunos autores han comenzado a explorar la influencia de la **fuente de alimentación** sobre la respuesta electroquímica del sistema. Investigaciones como las de Park et al. (2020) y Kim & Nguyen (2022) han reportado que el uso de **fuentes pulsadas** puede disminuir la formación de óxidos superficiales y mejorar la eficiencia de la transferencia de carga[@ref21]. Estas propuestas abren la posibilidad de combinar la modulación eléctrica con técnicas como EIS para realizar **análisis dinámicos de impedancia** que permitan estimar el estado interno del sistema en tiempo real.
> 
> En este contexto, persiste un vacío en la literatura respecto a estudios que integren la caracterización de impedancia con la variación controlada de la fuente de alimentación como herramienta para modelar, diagnosticar y anticipar el deterioro de los electrodos. Esta línea de investigación representa una oportunidad para desarrollar nuevas estrategias de **monitoreo no invasivo y modelado predictivo** en sistemas de producción de hidrógeno basados en electrólisis alcalina.


### Guía para escribir los antecedentes

> [!TIP] Describir el proceso o fenómeno central
> Presenta brevemente el proceso técnico o científico que está en el núcleo del problema.
> 
> Preguntas orientadoras:
> 
> - ¿Qué proceso estás investigando?
> - ¿Qué papel tiene dentro del campo científico o tecnológico?
> - ¿Cuáles son sus condiciones o principios clave? 
> 
> **Ejemplo:**
> 
> > _La electrólisis del agua es una tecnología fundamental para la producción de hidrógeno limpio. En sistemas alcalinos, este proceso implica la aplicación de corriente eléctrica sobre electrodos sumergidos en una solución electrolítica, generando gases $H_2$ y $O_2$._
> 


> [!TIP] Enunciar el problema operativo o técnico
> 
> Define claramente cuál es el problema que afecta el funcionamiento del sistema.
> 
> Preguntas orientadoras:
> 
> - ¿Qué está fallando o causando pérdidas?    
> - ¿Qué impacto tiene ese problema?
> - ¿Es un fenómeno físico, químico, eléctrico, mecánico?
> 
> Ejemplo:
> > _Uno de los principales desafíos es la degradación progresiva de los electrodos, especialmente en el ánodo, donde ocurre oxidación acelerada. Esto reduce su conductividad y disminuye la eficiencia del sistema._

> [!TIP] Revisar lo que otros autores han hecho para resolver el problema
> 
> Aquí detallas investigaciones previas y sus enfoques, técnicas o resultados. Es el núcleo de los antecedentes.
> 
> Preguntas orientadoras:
> - ¿Qué soluciones han intentado otros?
> - ¿Qué técnicas se han usado para estudiar o mitigar el problema?
> - ¿Qué resultados obtuvieron?
> 
> Ejemplo:
> 
> > *Se han propuesto recubrimientos protectores sobre los electrodos, como óxidos metálicos, para reducir su desgaste. Otros trabajos han modificado la composición del electrolito para mejorar su estabilidad y conductividad. En paralelo, se ha utilizado la espectroscopía de impedancia electroquímica (EIS) para evaluar de forma indirecta el deterioro de los electrodos, midiendo la resistencia de transferencia de carga y la resistencia óhmica del sistema [@ref3; @ref35].*

> [!TIP] Identificar las limitaciones de esas investigaciones
> 
> Señala qué no han logrado resolver completamente o qué falta por hacer.
> 
> Preguntas orientadoras:
> •	¿Qué debilidades tienen esas soluciones?
> •	¿Qué aspectos no abordaron?
> •	¿Qué no se puede observar o medir aún?
> 
> Ejemplo:
> 
> > *Aunque EIS ha sido útil como herramienta diagnóstica, su uso ha estado limitado a ensayos en condiciones controladas. Además, rara vez se ha combinado con variaciones en la fuente de alimentación durante la operación en tiempo real, lo que limita su utilidad como técnica de monitoreo continuo.*

> [!TIP] Justificar el vacío de conocimiento que cubrirá tu investigación
> 
> Cierra esta sección conectando las limitaciones detectadas con lo que tú propones estudiar.
> 
> Preguntas orientadoras:
> •	¿Qué aporta tu propuesta que otros no han explorado?
> •	¿Cómo cubrirás el vacío?
> •	¿Qué nuevo enfoque usarás?
> 
> Ejemplo:
> 
> > *Por lo tanto, es necesario estudiar cómo varía la impedancia del sistema bajo diferentes condiciones de operación real, incluyendo el uso de fuentes de alimentación pulsadas. Esto permitirá avanzar hacia un modelo dinámico que relacione la degradación interna con variables eléctricas observables, abriendo la posibilidad de implementar un sistema de diagnóstico no invasivo en electrolizadores alcalinos.*
> 


### Diferencias clave entre la introducción y antecedentes

| **Aspecto**                | **Introducción**                                | **Antecedentes**                                   |
| -------------------------- | ----------------------------------------------- | -------------------------------------------------- |
| Función principal          | Contextualizar y justificar el interés del tema | Revisar lo que ya se ha investigado sobre el tema  |
| Enfoque                    | General y motivacional                          | Específico, técnico y bibliográfico                |
| Relación con el problema   | Presenta el problema                            | Explica cómo ha sido abordado previamente          |
| Lugar dentro del protocolo | Sección inicial, antes de plantear el problema  | Después de la introducción, antes de los objetivos |

## Objetivos 
 
 La secciones de los objetivos, generales y específicos, son una ratificación de las intenciones y alcances previamente indicados en las secciones de introducción y antecedentes; no obstante así es la redacción de protocolos de investigación clara, concisa y en ocasiones reiterativa.

### Objetivo general

Un objetivo general describe qué se quiere lograr con la investigación en términos amplios.
 Expresar el fin principal de la investigación, de manera clara, concreta y alcanzable.

📌 **Su propósito: Expresar el fin principal de la investigación, de manera clara, concreta y alcanzable.**

¿Cómo redactarlo?

Usa verbos en infinitivo como:
	•	Analizar
	•	Evaluar
	•	Determinar
	•	Implementar
	•	Caracterizar
	•	Proponer
	•	Estudiar

**Evite formular objetivos con verbos poco operativos, como conocer o comprender, pues dificultan la evaluación de los resultados.**

> [!TIP] Ejemplo (tema: impedancia y degradación de electrodos):
> **Objetivo general:**
> 
> Evaluar la influencia de la fuente de alimentación pulsada en la degradación de los electrodos de un electrolizador alcalino, mediante el análisis de impedancia eléctrica durante distintas fases operativas del sistema.
> 

### Objetivos específicos

Los objetivos específicos detallan los pasos concretos o acciones que permitirán alcanzar el objetivo general.

📌 **Su propósito: Desglosar el objetivo general en tareas o metas más pequeñas, organizadas de forma lógica o cronológica.**

¿Qué deben hacer?
•	Abordar una sola acción clara por objetivo.
•	Ser medibles y observables.
•	Llevar un orden lógico: desde la caracterización hasta la propuesta o validación.

¿Cómo redactarlos?

También usan verbos en infinitivo, como:
- Identificar
- Medir
- Modelar
- Comparar
- Validar
- Registrar
- Diseñar
- Implementar
- Simular
- Determinar
- Desarrollar
- Actualizar
- Gestionar

> [!tip] Ejemplo (continuación del anterior):
> 
> Objetivos específicos:
> 	1.	Caracterizar el comportamiento eléctrico de los electrodos en condiciones normales de operación con fuente de corriente continua.
> 	2.	Implementar una fuente de alimentación pulsada para el sistema de electrólisis alcalina.
> 	3.	Registrar y analizar la impedancia del sistema en distintas fases operativas (óptima, electrolito degradado, sobresaturación).
> 	4.	Comparar los parámetros de impedancia entre operación con corriente continua y pulsada.
> 	5.	Determinar la relación entre la variación de impedancia y el nivel de degradación de los electrodos.


## Marco teórico

La investigación que se propone **debe de estar apoyada por una teoría, metodología o hipótesis principal**. En esta sección se debe de desarrollar y exponer a detalle los fundamentos técnico-científico que respaldan nuestra propuesta.

En consecuencia, el revisor de nuestro protocolo debe comprender el fundamento científico y técnico que apoya nuestra propuesta, y debe quedar claro que estás construyendo tu investigación sobre un cuerpo de conocimiento sólido.

En ese sentido, considera como parte principal de tu marco teórico el tópico o técnica preponderante de tu proyecto de investigación. Por ejemplo, si tu trabajo considera el desarrollo de un control inteligente, éste puede ser un punto no tan ampliamente conocido por los revisores y por lo tanto ser sujeto de duda en la investigación. 

Otro ejemplo puede ser, para un estudio de parámetros fisiológicos en prótesis dentales apoyados por impresión 3D y modelos estadísticos, el marco teórico debe de cubrir ambos temas. Veamos a detalle este caso particular:

> [!example] Impresión 3D en odontología digital
> 
> La impresión 3D ha transformado la odontología restaurativa al permitir la fabricación rápida, precisa y personalizada de coronas, puentes, férulas, guías quirúrgicas e incluso modelos de estudio. Esta tecnología se basa en técnicas como la estereolitografía (SLA), la fotopolimerización por luz dirigida (DLP) o la impresión por resina líquida (LCD), las cuales solidifican materiales biocompatibles capa por capa a partir de un diseño digital. La posibilidad de fabricar piezas con geometrías complejas y adaptadas a las características del paciente ha motivado la necesidad de evaluar estadísticamente su calidad, precisión dimensional y comportamiento clínico.
> 
> 
> Dado el creciente uso de tecnologías CAD/CAM e impresión 3D en la fabricación de prótesis dentales, es fundamental incorporar herramientas estadísticas que permitan analizar la variabilidad en el proceso y optimizar parámetros de impresión. El modelado estadístico permite, por ejemplo, evaluar el impacto de variables como el tipo de resina, la orientación de impresión, el grosor de capa o el tiempo de curado sobre la precisión marginal, el ajuste o la durabilidad de las restauraciones.
>
> 
> El análisis de varianza (ANOVA) es una técnica estadística frecuentemente utilizada para comparar la precisión dimensional entre diferentes materiales o configuraciones de impresión. Por ejemplo, en estudios que evalúan la desviación entre el diseño original y la pieza impresa, el ANOVA permite determinar si existen diferencias estadísticamente significativas entre grupos con distintos tipos de resina o resoluciones de impresión.

# Sintaxis básica de Markdown

A continuación se muestra la sintaxis para definir títulos, subtítulos y (sub)subtítulos:
```
# Título 
## Subtítulo
### Subsubtítulo

```

Este es un ejemplo de **texto con formato bold**. 
Texto *con cursiva.*  
Un texto con [[presentacion.pdf]]

Listas sin enumerar:
- Primer elemento
- Segundo elemento
- Tercer elemento
	- Lista anidada
	- otro elemento anidado



Lista enumerada: 
1. Primer
2. Segundo 
3. Tercer
4. Etc.

Ecuaciones en texto $f(x)=x^2$ y ecuaciones enumeradas:

$$ f(x)=\int_{0}^{\infty} \sin(x) dx $$ 

# Lecturas recomendadas

- A manual for writers of research papers, theses and disserattions
- Scientific paper writing: A survival guide
- Science research writing for non native speakers of english

![[201004.jpg]]

![[107853_survival-guide.jpg]]


![[61feW66akwL._UF1000,1000_QL80_.jpg]]

# Todo












